@@ -137,8 +137,8 @@ typedef enum {
  * @GST_FLOW_EOS:                Pad is EOS.
  * @GST_FLOW_NOT_NEGOTIATED:	 Pad is not negotiated.
  * @GST_FLOW_ERROR:		 Some (fatal) error occurred. Element generating
- *                               this error should post an error message with more
- *                               details.
+ *                               this error should post an error message using
+ *                               GST_ELEMENT_ERROR() with more details.
  * @GST_FLOW_NOT_SUPPORTED:	 This operation is not supported.
  * @GST_FLOW_CUSTOM_SUCCESS:	 Elements can use values starting from
  *                               this (and higher) to define custom success
@@ -548,9 +548,12 @@ typedef enum
  *        the data item is not passed upstream. In both cases, no other probes
  *        are called for this item and %GST_FLOW_OK or %TRUE is returned to the
  *        caller.
- * @GST_PAD_PROBE_REMOVE: remove this probe.
+ * @GST_PAD_PROBE_REMOVE: remove this probe, passing the data. For blocking probes
+ *        this will cause data flow to unblock, unless there are also other
+ *        blocking probes installed.
  * @GST_PAD_PROBE_PASS: pass the data item in the block probe and block on the
- *        next item.
+ *        next item. Note, that if there are multiple pad probes installed and
+ *        any probe returns PASS, the data will be passed.
  * @GST_PAD_PROBE_HANDLED: Data has been handled in the probe and will not be
  *        forwarded further. For events and buffers this is the same behaviour as
  *        %GST_PAD_PROBE_DROP (except that in this case you need to unref the buffer
@@ -1246,6 +1249,34 @@ struct _GstPadClass {
  * when buffers or serialized downstream events are pushed on a pad.
  */
 #define GST_PAD_STREAM_LOCK(pad)        g_rec_mutex_lock(GST_PAD_GET_STREAM_LOCK(pad))
+
+/**
+ * GST_PAD_STREAM_AUTO_LOCK
+ * @pad: a #GstPad
+ * @var: a variable name to be declared
+ *
+ * Declare a #GRecMutexLocker variable with g_autoptr() and lock the pad. The
+ * recursive mutex will be unlocked automatically when leaving the scope.
+ *
+ * ``` c
+ * {
+ *   GST_PAD_STREAM_AUTO_LOCK (pad, locker);
+ *
+ *   gst_pad_push_event(pad, event1);
+ *   if (cond) {
+ *     // No need to unlock
+ *     return;
+ *   }
+ *
+ *   // Unlock before end of scope
+ *   g_clear_pointer (&locker, g_rec_mutex_locker_free);
+ *   gst_pad_push_event(pad, event2);
+ * }
+ * ```
+ * Since: 1.24.0
+ */
+#define GST_PAD_STREAM_AUTO_LOCK(pad, var) g_autoptr(GRecMutexLocker) G_GNUC_UNUSED var = g_rec_mutex_locker_new(GST_PAD_GET_STREAM_LOCK(pad))
+
 /**
  * GST_PAD_STREAM_TRYLOCK:
  * @pad: a #GstPad
